powered by
This function creates a dummy variable indicating whether a code represents 'ABA'.
create_is_aba(codes_df)
A dataframe of codes with an additional column indicating whether the code represents 'ABA'.
A dataframe of binary codes generated by the generate_codes function.
speaker_no <- c(3, 2, 3, 1, 4, 2, 4, 1, 4, 3, 2, 3) sequences_df <- generate_sequences(speaker_no, 3) codes_df <- generate_codes(sequences_df) create_is_aba(codes_df)
Run the code above in your browser using DataLab