powered by
This function counts the number of occurrences of each unique event in a sequence. The result is a dataframe with two columns: ID and Frequency.
count_events(event_vector)
A dataframe with two columns: ID and Frequency, showing the number of occurrences of each event.
A numeric vector representing a sequence of events.
speaker_no <- c(3, 2, 3, 1, 4, 2, 4, 1, 4, 3, 2, 3) count_events(speaker_no)
Run the code above in your browser using DataLab